@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2016  B.A.T.M.A.N. contributors:
+ * Copyright (C) 2007-2017  B.A.T.M.A.N. contributors:
  *
  * Andreas Langer <an.langer@gmx.de>, Marek Lindner <mareklindner@neomailbox.ch>
  *
@@ -1138,3 +1138,11 @@ void get_random_bytes(void *buf, size_t buflen)
 
 	get_random_bytes_fallback(buf, buflen);
 }
+
+void check_root_or_die(const char *cmd)
+{
+	if (geteuid() != 0) {
+		fprintf(stderr, "Error - you must be root to run '%s' !\n", cmd);
+		exit(EXIT_FAILURE);
+	}
+}
